package com.goldenwater.slaj.eutr.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.goldenwater.slaj.eutr.mapper.BisEutrCourCateMapper;
import com.goldenwater.slaj.eutr.domain.BisEutrCourCate;
import com.goldenwater.slaj.eutr.service.IBisEutrCourCateService;

@Service
public class BisEutrCourCateServiceImpl implements IBisEutrCourCateService {
    @Autowired
    private BisEutrCourCateMapper bisEutrCourCateMapper;

    @Override
    public BisEutrCourCate selectBisEutrCourCateByGuid(String guid) {
        return bisEutrCourCateMapper.selectBisEutrCourCateByGuid(guid);
    }

    @Override
    public List<BisEutrCourCate> selectBisEutrCourCateList(BisEutrCourCate bisEutrCourCate) {
        return bisEutrCourCateMapper.selectBisEutrCourCateList(bisEutrCourCate);
    }

    @Override
    public int insertBisEutrCourCate(BisEutrCourCate bisEutrCourCate) {
        return bisEutrCourCateMapper.insertBisEutrCourCate(bisEutrCourCate);
    }

    @Override
    public int updateBisEutrCourCate(BisEutrCourCate bisEutrCourCate) {
        return bisEutrCourCateMapper.updateBisEutrCourCate(bisEutrCourCate);
    }

    @Override
    public int deleteBisEutrCourCateByGuid(String guid) {
        return bisEutrCourCateMapper.deleteBisEutrCourCateByGuid(guid);
    }

    @Override
    public int deleteBisEutrCourCateByGuids(String[] guids) {
        return bisEutrCourCateMapper.deleteBisEutrCourCateByGuids(guids);
    }
}
